@@ -154,7 +154,7 @@ async def _inplace_change(filename, old_string, new_string):
 async def _append_line(filename, line):
     print(filename, line)
     append_file = open(filename, "a")
-    append_file.write(line)
+    append_file.write("\n" + line)
     append_file.close()
 
 @asyncio.coroutine
